'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = "#splitter_root__2G5BU{height: 100%;}\n\n/* 가로 모드 CSS */\n.splitter_sp_table__3eTha{display:table;table-layout:fixed;width:100%;height:100%;}\n.splitter_sp_h_row__Uav9Q{display:table-row;height:100%;}\n.splitter_sp_h_cell__2O03F{position: relative;display:table-cell;vertical-align:top;/*overflow-x: auto;*/}\n.splitter_sp_h_bar__ePcJ8{position: relative;display:table-cell;width:8px;cursor:ew-resize;border-left: 1px solid rgb(238, 238, 238); border-right: 1px solid rgb(102, 102, 102); box-sizing: border-box; background-color: rgb(192, 192, 192);}\n/* 세로 모드 CSS */\n.splitter_sp_v_row__AUugs{display:table-row;width: 100%;}\n.splitter_sp_v_bar__3hrJ9{display:table-row;}\n.splitter_sp_v_bar_cell__3D4bJ{display:table-cell;height: 8px;cursor:n-resize;border-top: 1px solid rgb(238, 238, 238); border-bottom: 1px solid rgb(102, 102, 102); background-color: rgb(192, 192, 192);}\n.splitter_sp_v_cell__2aWsn{display:table-cell;vertical-align:top;overflow-x: auto;}";
var styles = { "root": "splitter_root__2G5BU", "sp_table": "splitter_sp_table__3eTha", "sp_h_row": "splitter_sp_h_row__Uav9Q", "sp_h_cell": "splitter_sp_h_cell__2O03F", "sp_h_bar": "splitter_sp_h_bar__ePcJ8", "sp_v_row": "splitter_sp_v_row__AUugs", "sp_v_bar": "splitter_sp_v_bar__3hrJ9", "sp_v_bar_cell": "splitter_sp_v_bar_cell__3D4bJ", "sp_v_cell": "splitter_sp_v_cell__2aWsn" };
styleInject(css);

var slicedToArray = function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
}();

/**
* 화면분할 라이브러리
* @since 20.01.25
* @author 김종민
* @param {string} mode - h: 가로 분할, v: 세로 분할
* @param {number} minSize - 축소 가능한 최소 크기 : 버튼으로 축소 하는 기능때문에 사라짐
* @param {number} oneSize - 초기 크기 지정 : w일때는 좌측, h일때는 상단의 크기를 변경
*/

var Splitter = function Splitter(props) {
  var children = props.children,
      option = props.option;
  // let child = React.Children.toArray(props.children);

  var _children = slicedToArray(children, 2),
      First = _children[0],
      Second = _children[1];

  var wrapRef = React.useRef();

  // console.log(children)
  var initWidth = void 0;
  var initHeight = void 0;
  try {
    if (option.oneSize && option.oneSize != 0) {
      if (option.mode === "h") initWidth = option.oneSize + "px";
      if (option.mode === "v") initHeight = option.oneSize + "px";
    }
    if (children.length > 2) {
      throw new Error('\n[Error] Splitter should have only 2 children components. \n[에러] Splitter 내부에 자식 컴포넌트는 2개만 있어야 합니다.');
    }
    if (!option.mode || option.mode !== "h" && option.mode !== "v") throw new Error('\nobject option should have "mode" property. "h" is horizontal and "v" is vertical \n option 객체안에 mode가 없습니다 "h"는 가로모드, "v"는 세로모드 입니다.');
  } catch (error) {
    console.error(error);
  }

  var mouseDownfn = function mouseDownfn(e) {
    // 드래그시 영역의 텍스트 드래그 방지
    if (e.preventDefault) e.preventDefault();
    // 마우스 이벤트 동작
    var areaNode = wrapRef.current;
    document.addEventListener("mousemove", fnMouseMove);
    document.addEventListener("mouseup", fnMouseUp);

    // console.log(wrapRef.current.getBoundingClientRect())

    var that = option;
    // 마우스 움직일때 이벤트
    function fnMouseMove(e) {
      var rect = areaNode.getBoundingClientRect();

      if (that.mode === "h") {
        // 가로 분할    
        //let posX = e.screenX - window.screenX - rect.left;
        var posX = e.clientX - rect.left;
        var lSection = areaNode.children[0].children[0];
        var rSection = areaNode.children[0].children[2];

        if (posX > areaNode.offsetWidth - that.minSize) ; else if (posX < that.minSize) {
          lSection.style.width = that.minSize + "px";
        } else {
          lSection.style.width = posX + "px";
        }
      } else if (that.mode === "v") {
        // 세로 분할
        // console.log(e.clientY, rect.top)
        var posY = e.clientY - rect.top;
        var tSection = areaNode.children[0].children[0];
        var bSection = areaNode.children[0].children[2];

        if (posY > areaNode.offsetHeight - that.minSize) ; else if (posY < that.minSize) {
          tSection.style.height = that.minSize + "px";
        } else {
          tSection.style.height = posY + "px";
        }
      }
      // 드래그시 영역의 텍스트 드래그 방지
      if (e.preventDefault) e.preventDefault();
    }
    // 마우스 손뗄때 이벤트
    function fnMouseUp(e) {
      document.removeEventListener("mousemove", fnMouseMove);
      document.removeEventListener("mouseup", fnMouseUp);
    }
  };

  if (option.mode === 'v') {
    return React__default.createElement(
      'div',
      { className: styles.sp_table, ref: wrapRef },
      React__default.createElement(
        'div',
        { className: styles.sp_v_row },
        React__default.createElement(
          'div',
          { className: styles.sp_v_cell, style: { height: initHeight } },
          First
        )
      ),
      React__default.createElement(
        'div',
        { className: styles.sp_v_bar, onMouseDown: mouseDownfn },
        React__default.createElement('div', { className: styles.sp_v_bar_cell })
      ),
      React__default.createElement(
        'div',
        { className: styles.sp_v_row },
        React__default.createElement(
          'div',
          { className: styles.sp_v_cell },
          Second
        )
      )
    );
  } else {
    return React__default.createElement(
      'div',
      { className: styles.sp_table, ref: wrapRef },
      React__default.createElement(
        'div',
        { className: styles.sp_h_row },
        React__default.createElement(
          'div',
          { className: styles.sp_h_cell, style: { width: initWidth } },
          First
        ),
        React__default.createElement('div', { className: styles.sp_h_bar, onMouseDown: mouseDownfn }),
        React__default.createElement(
          'div',
          { className: styles.sp_h_cell },
          Second
        )
      )
    );
  }
};

module.exports = Splitter;
//# sourceMappingURL=index.js.map
